@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.040002";
+$VERSION = "5.042000";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.40.2) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.42.0) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.40.2
-    or die sprintf "%s: Perl lib version (5.40.2) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.42.0
+    or die sprintf "%s: Perl lib version (5.42.0) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -84,7 +84,7 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/usr/pkg/lib/perl5/5.40.0/powerpc-netbsd-thread-multi',
+    archlibexp => '/usr/pkg/lib/perl5/5.42.0/powerpc-netbsd-thread-multi',
     archname => 'powerpc-netbsd-thread-multi',
     cc => 'gcc',
     d_readlink => 'define',
@@ -96,16 +96,16 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/lib /usr/lib /usr/pkg/lib',
+    libpth => '/lib /usr/lib /usr/local/lib /usr/pkg/lib',
     osname => 'netbsd',
-    osvers => '10.99.14',
+    osvers => '10.0',
     path_sep => ':',
-    privlibexp => '/usr/pkg/lib/perl5/5.40.0',
+    privlibexp => '/usr/pkg/lib/perl5/5.42.0',
     scriptdir => '/usr/pkg/lib/perl5/bin',
-    sitearchexp => '/usr/pkg/lib/perl5/site_perl/5.40.0/powerpc-netbsd-thread-multi',
-    sitelibexp => '/usr/pkg/lib/perl5/site_perl/5.40.0',
+    sitearchexp => '/usr/pkg/lib/perl5/site_perl/5.42.0/powerpc-netbsd-thread-multi',
+    sitelibexp => '/usr/pkg/lib/perl5/site_perl/5.42.0',
     so => 'so',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.40.2',
+    version => '5.42.0',
 };
